@@ -13,7 +13,9 @@ from robin_sd_upload.supportive_scripts import logger
 from robin_sd_upload.supportive_scripts import validate
 from robin_sd_upload.supportive_scripts import create_zip
 from robin_sd_upload.supportive_scripts import remove_zip
-from robin_sd_upload.supportive_scripts import check_upload_file
+# from robin_sd_upload.supportive_scripts import check_upload_file
+from arg_parse import check_upload_file
+
 
 def arg_parser():
     parser = argparse.ArgumentParser(
@@ -54,7 +56,7 @@ def arg_parser():
             print('Please provide all the arguments: --type, --version, --source')
             exit(1)
         # check if the radar type is valid
-        validate(radarType, version_name)
+        # validate(radarType, version_name)
         if check_upload_file(upload_file_path, version_name) is False:
             exit(1)
         temp_dir = tempfile.mkdtemp()
